@@ -103,6 +103,20 @@ def mpich_config(mpich, name)
   }
 end
 
+def inetd_config(file)
+  io_w = File.open( "/tmp/tmpfile" , "w")
+
+  open(file){|io_r|
+    while line = io_r.gets
+      io_w.puts( line.gsub( /\/var\/lib\/tftpboot/, '/tftpboot' ) )
+    end
+  }
+  
+  io_w.close()
+
+  File.move("/tmp/tmpfile", file)
+end
+
 def dhcpd_config(dhcp, dhcp_i, tftpboot, master_eth, master_ip, nwork, nmask, bcast, slave_name, slave_ip, slave_mac)
   File.open(dhcp_i, "w"){|io|
     io.puts "# dcast create"
