@@ -157,8 +157,8 @@ def mkdir_tftpboot(tftpboot, kernel, initrd, master_ip)
   system("ln -sf /ram/ifstate #{tftpboot_b + "/etc/network/ifstate"}")
 
   # kernel
-  FileUtils.cp(kernel, tftpboot + "/")
-  FileUtils.cp(initrd, tftpboot + "/")
+  FileUtils.cp(kernel, tftpboot + "/bzImage")
+  FileUtils.cp(initrd, tftpboot + "/initrd.img")
 
   $stdout.puts ". Done."
 end
