@@ -45,7 +45,7 @@ mke2fs $ROOTDEVICE
 tune2fs -j -c0 -i0 $ROOTDEVICE
 
 # Make ROOTDEVICE
-mount $ROOTDEVICE /mnt
+mount -n $ROOTDEVICE /mnt
 
 function tar_cp(){
     cp /root.tgz /mnt/
@@ -90,7 +90,7 @@ rm /mnt/etc/init.d/dcast-nfsmount
 rm /mnt/etc/rcS.d/S44dcast-nfsmount
 cd
 umount /mnt
-mount -t ext3 $ROOTDEVICE /mnt
+mount -n $ROOTDEVICE /mnt
 exec /usr/sbin/chroot /mnt /sbin/init
 EOB
   }
@@ -109,12 +109,11 @@ diskflag=false
 for hdd in /dev/hd[a-d] /dev/sd[a-d]; do
   if dd if=$hdd of=/dev/null count=1 2> /dev/null; then
     diskflag=true
-    /etc/init.d/portmap start
-    mount -t nfs $MASTER:/tftpboot/slave/ /mnt 
+    mount -n -o nolock -t nfs $MASTER:/tftpboot/slave/ /mnt 
       if [ -f /mnt/$(hostname) ] ; then
       if [ $(head -1 /mnt/$(hostname)) == "1" ] ; then
         umount /mnt
-        mount -t ext3 $hdd"2" /mnt
+        mount -n -t ext3 $hdd"2" /mnt
         exec /usr/sbin/chroot /mnt /sbin/init
         break
       elif [ $(head -1 /mnt/$(hostname)) == "0" ] ; then
@@ -158,7 +157,7 @@ for hdd in /dev/hd[a-d] /dev/sd[a-d]; do
   fi
 done
 
-mount -t nfs $MASTER:/tftpboot/slave /mnt 2> /dev/null
+mount -n -t nfs $MASTER:/tftpboot/slave /mnt 2> /dev/null
 case $diskflag in
    true)
    if [ ! -f /mnt/$(hostname) ] ; then
