@@ -48,8 +48,8 @@ EOF
 end
 
 def slave_hosts_config(diskless, ip, name, domain)
+  IO.popen('sed "s/^127/#127/g" /etc/hosts >> /tmp/hosts')
   IO.popen('echo "127.0.0.1        localhost" > /tmp/hosts')
-  IO.popen('sed "s/^127\.0\.0\.1/#127\.0\.0\.1/g" /etc/hosts >> /tmp/hosts')
   IO.popen('sync')
 
   FileUtils.cp("/tmp/hosts", diskless + "/etc/hosts")
